@@ -10,7 +10,6 @@ from mongoengine.base import ValidationError
 
 from flask import abort
 
-
 def _include_mongoengine(obj):
     for module in mongoengine, mongoengine.fields:
         for key in module.__all__:
@@ -22,9 +21,11 @@ class MongoEngine(object):
 
     def __init__(self, app=None):
 
-        self.Document = Document
         _include_mongoengine(self)
 
+        self.Document = Document
+        self.Document = DynamicDocument
+
         if app is not None:
             self.init_app(app)
 
@@ -81,12 +82,12 @@ class Document(mongoengine.Document):
     meta = {'abstract': True,
             'queryset_class': BaseQuerySet}
 
-# TODO rocloutier: Cannot find a mongoengine version that has DynamicDocument
-# class DynamicDocument(mongoengine.DynamicDocument):
-#     """Abstract Dynamic document with extra helpers in the queryset class"""
 
-#     meta = {'abstract': True,
-#             'queryset_class': BaseQuerySet}
+class DynamicDocument(mongoengine.DynamicDocument):
+    """Abstract Dynamic document with extra helpers in the queryset class"""
+
+    meta = {'abstract': True,
+            'queryset_class': BaseQuerySet}
 
 
 class Pagination(object):
